@@ -9,7 +9,7 @@ comments = {
         "license": {"start": " * ---", "end": " * ---"},
     },
     "sh": {
-        "start": "###############################################################################",
+        "start": "#",
         "char": "#",
         "line": "#",
         "end": "#",
